# HEAL Data Utilities

The HEAL Data Utilities python package provides data packaging tools for the HEAL Data Ecosystem to facilitate data discovery, sharing, and harmonization on the [HEAL Platform](https://healdata.org).
 
Currently, the focus of this repository is generating standardized variable level metadata (VLMD) in the form of data dictionaries. See the documentation [here](https://heal.github.io/healdata-utils/)
However, in the future, this will be expanded for all HEAL-specific data packaging functions (e.g., study- and file-level metadata and data).

## Prerequisites

### Python

While the HEAL Data Utilities should be compatible with most versions of Python, you can download the latest version of Python [here](https://www.python.org/downloads/) and install it on your local computer. We recommend installing Python version 3.10.

## Installation

To install the latest official release of healdata-utils, from your computer's command prompt, run:

`pip install healdata-utils`

OR for the most up-to-date unreleased version run: 

`pip install git+https://github.com/heal/healdata-utils.git`

!!! note

    Installing the unreleased version requires having [`git` software
    installed](https://git-scm.com/downloads).

